# Generated by using Rcpp::compileAttributes() -> do not edit by hand
# Generator token: 10BE3573-1514-4C36-9D1C-5A225CD40393

#' Response computation
#'
#' Compute response acceleration, pseudo-spectral acceleration (PSA), and spectral displacement
#'
#' @param data An acceleration time series array
#' @param period_t An array of oscillator periods
#' @param damping Damping ratio, expressed as a decimal (default value is 0.05)
#' @param time_dt Time step, in sec
#' @param type_return A dummy variable controlling output type, set to either 1 or 2.
#' If 1 is selected, it returns a two-row matrix with actual spectral acceleration
#' in the first row and PSA in the second row. If 2 is selected,
#' it returns a row vector of spectral displacements
#' @return The response acceleration and PSA, or spectral displacement. It depends on \code{type_return}.
#' @export
#' @examples
#' PS_cal_cpp(c(0.01,0.03,...0.5), c(0.01,0.02,...10), 0.05, 0.005, 1)
PS_cal_cpp <- function(data, period_t, damping, time_dt, type_return) {
    .Call('_RCTC_PS_cal_cpp', PACKAGE = 'RCTC', data, period_t, damping, time_dt, type_return)
}

#' Subset selection
#'
#' Select subsets of two components of ground motions.
#'
#' @param data1 One horizontal component of ground motions
#' @param data2 Another horizontal component of ground motions
#' @param fraction A factor to specify how much subset will be selected.
#' 0 means select all dataset.
#' @param length The minimum length of two input time sereis, integer type
#' @param time_dt Time step, double type
#' @param type_return Either 1 or 2. It specifies what does this \code{subset_select} return.
#' If set as 1, it will return a matirx (length is the length of selected subset,
#' width is 3) for subset. The first row is subset selection for \code{data1}, the second row is
#' subset selection for \code{data2}, while the third row is subset selection for time.
#' If set as 2, it will return only a double type value, which is threshold value for subset selection
#' @return \code{subset_select} returns two subsets of \code{data1} and \code{data2}, or a threshold value.
#' It depends on \code{type_return}.
#' @export
#' @examples
#' subset_select(c(0.01,0.03,...0.5), c(-0.01,0.02,...0.05), 0.7, 2500, 0.005, 1)
subset_select <- function(data1, data2, fraction, length, time_dt, type_return) {
    .Call('_RCTC_subset_select', PACKAGE = 'RCTC', data1, data2, fraction, length, time_dt, type_return)
}

